@@ -6,5 +6,5 @@ m1 <- ggm(~.^.,gmData=car)
 
 m1 <- fit(m1)
 
-dynamic.Graph(m1)
+#dynamic.Graph(m1)
 
